pub struct PdfString { /* private fields */ }Expand description
A PDF literal string object, e.g., (Hello World).
Implementations
Sourceimpl PdfString
impl PdfString
pub fn of(value: &str) -> Self
Sourcepub fn as_bytes_decoded(&self) -> Vec<u8> ⓘ
pub fn as_bytes_decoded(&self) -> Vec<u8> ⓘ
Convert the string to raw bytes, interpreting escape sequences. Characters are treated as Latin-1 code points (0..=255), not UTF-8.
Sourcepub fn decode_text(&self) -> String
pub fn decode_text(&self) -> String
Decode the string to a text String, handling UTF-16 and PDFDocEncoding.